# Python Package helper
Python Package helper CLI 

### LEARN

[Learn about Python packaging](https://packaging.python.org/en/latest/)

[Simple Python packaging tuitorial](https://packaging.python.org/en/latest/tutorials/packaging-projects/)


## Installation
```
pip install git+https://github.com/dviralfi/HelpMePack.git
```

## Usage

Please make sure you have your '.git' folder, and README.md, .gitignore, requirments.txt, LICENSE files - in your project directory.

All the other project files will be moved to the 'src' folder.

Make sure you running in the Project Main Directory


## 
Run Python (in cmd/bash) in your project directory 

```
from helpmepack import helpmepack 
```

```
helpmepack.main()
```
